@@ -7,8 +7,11 @@
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
-package Config::Model::Backend::OpenSsh::Ssh v2.7.9.1;
+use strict;
+use warnings;
 
+package Config::Model::Backend::OpenSsh::Ssh ;
+$Config::Model::Backend::OpenSsh::Ssh::VERSION = '2.7.9.2';
 use Mouse ;
 use 5.10.1;
 extends "Config::Model::Backend::Any" ;
@@ -152,7 +155,7 @@ Config::Model::Backend::OpenSsh::Ssh - Backend for ssh configuration files
 
 =head1 VERSION
 
-version v2.7.9.1
+version 2.7.9.2
 
 =head1 SYNOPSIS
 
