@@ -7,8 +7,11 @@
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
-package Config::Model::Backend::OpenSsh::Sshd v2.7.9.1;
+use strict;
+use warnings;
 
+package Config::Model::Backend::OpenSsh::Sshd ;
+$Config::Model::Backend::OpenSsh::Sshd::VERSION = '2.7.9.2';
 use Mouse ;
 extends "Config::Model::Backend::Any" ;
 
@@ -54,7 +57,7 @@ Config::Model::Backend::OpenSsh::Sshd - Backend for sshd configuration files
 
 =head1 VERSION
 
-version v2.7.9.1
+version 2.7.9.2
 
 =head1 SYNOPSIS
 
