@@ -1,25 +1,26 @@
 #
 # This file is part of Config-Model-OpenSsh
 #
-# This software is Copyright (c) 2013 by Dominique Dumont.
+# This software is Copyright (c) 2008-2019 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 use strict;
-
-use Config::Model::BackendMgr;
+use warnings;
 
 # test loading layered config à la ssh_config
 
-$model_to_test = "SystemSsh";
-$conf_file_name = "ssh_config";
-$conf_dir= '/etc/ssh';
-
-@tests = (
+my @tests = (
     {    # t0
         name  => 'basic',
+        setup => {
+            'system_ssh_config' => {
+                'darwin' => '/etc/ssh_config',
+                'default' => '/etc/ssh/ssh_config',
+            },
+        },
         check => {
             'Host:"*" Ciphers' => 'aes128-ctr,aes192-ctr,aes256-ctr,arcfour256,arcfour128,aes128-cbc,3des-cbc',
             'Host:"*" IdentityFile:1' => '~/.ssh/id_rsa',
@@ -33,4 +34,6 @@ $conf_dir= '/etc/ssh';
     }
 );
 
-1;
+return {
+    tests => \@tests,
+};
